Learn R Programming

synlik (version 0.1.0)

blowSimul: Simulates from the blowfly model

Description

Simulator for the blowfly model proposed by Wood (2010).

Usage

blowSimul(param, nsim, extraArgs, ...)

Arguments

param
vector of log-parameters: delta, P, N0, var.p, tau and var.d. The interpretation of these parameters is described in Wood (2010).
nsim
Number of simulations from the model.
extraArgs
A named list of additional arguments:
  • nObs= Length of each simulated time series.
nBurn = Number of initial steps to be discarded before saving the following nObs steps. <

Value

  • A matrix nsim by nObs, where each row is a simulated path.

item

...

code

synlik

References

Simon N Wood. Statistical inference for noisy nonlinear ecological dynamic systems. Nature, 466(7310):1102--1104, 2010. Brillinger, D. R., J. Guckenheimer, P. Guttorp, and G. Oster. 1980. Empirical modelling of population time series data: the case of age and density dependent vital rates. Lectures on Mathematics in the Life Sciences13:65-90. Nicholson, A. J. 1957. The self-adjustment of populations to change. Cold Spring Harbor Symposia on Quantitative Biology22:153-173.

See Also

blow_sl

Examples

Run this code
tmp <- blowSimul(param = log( c( "delta" = 0.16, "P" = 6.5, "N0" = 400,
                                 "var.p" = 0.1, "tau" = 14, "var.d" = 0.1)  ),
                 nsim = 2,
                 extraArgs = list("nObs" = 200, "nBurn" = 1000, "steps" = 2))
matplot(t(tmp), type = 'l', ylab = "Y", xlab = "Time")

Run the code above in your browser using DataLab